@@ -3,7 +3,7 @@ import xml.etree.ElementTree as ET
 
 import numpy as np
 from ase import Atoms as ASEAtoms
-from pyiron_base import InputList
+from pyiron_base import DataContainer
 from pyiron import pyiron_to_ase, ase_to_pyiron, Atoms
 
 from pyiron_contrib.atomistic.atomicrex.fit_properties import ARFitPropertyList, ARFitProperty
